
tailbone-harvest
================

Rattail is a retail software framework, released under the GNU General
Public License.

This package contains software interfaces for `Harvest`_.

.. _`Harvest`: https://www.getharvest.com/

Please see the `Rattail Project`_ for more information.

.. _`Rattail Project`: https://rattailproject.org/
